%define current_version 7.0.254

%global _hardened_build 1

%define _vzdir /etc/vz
%define _confdir %{_vzdir}/conf
%define _namesdir %{_vzdir}/names
%define _spooldir /var/vz
%define _bashcompldir /etc/bash_completion.d
%define _lockdir /vz/lock
%define _vzctl_lockdir /var/lock/vzctl
%define _configdir /etc/vz/conf
%define _netdir	/etc/sysconfig/network-scripts
%define _logrdir /etc/logrotate.d
# rh macros defines _mandir incrorrectly
%define _mandir %{_datadir}/man
%define _kernel_ver 2.6.32
%define _incdir /usr/include/vz
%define _basename vzctl
%define _dracutmodulesdir %{_prefix}/lib/dracut/modules.d
%{?coverage:%define _coverage %{coverage}}
%{!?coverage:%define _coverage 0}

ExclusiveArch: x86_64
%if %_coverage
Name: %{_basename}-coverage
Provides: %{_basename}
Obsoletes: %{_basename}
%else
Name: %{_basename}
%endif
Summary: Containers control utility
Version: %{current_version}
Release:        1%{?dist}
License: GPLv2
Group: System Environment/Kernel
Source: %{name}-%{version}.tar.bz2
ExclusiveOS: Linux
BuildRoot: %{_tmppath}/%{_basename}-%{version}-root
BuildRequires: glibc-devel libuuid-devel
# these reqs are for vz helper scripts
Requires: bash
Requires: gawk
Requires: sed
Requires: ed
Requires: grep
Requires: ethtool
Requires: /sbin/chkconfig
Requires: vztt >= 5.0.0-48
Requires: fileutils
Requires: tar
Requires: e2fsprogs-libs
Requires: libvzctl >= 7.0.661
BuildRequires: e2fsprogs-devel systemd-devel
BuildRequires: libvzctl-devel >= 7.0.661
BuildRequires: ploop-devel >= 7.0.1-1
BuildRequires: vzkernel-headers

%description
This utility allows system administator to control Virtual Environment,
e.g. create, start, shutdown, set various options and limits etc.

%prep
%setup -n %{name}-%{version}
%build
%if %_coverage
make CFLAGS="-fprofile-arcs -ftest-coverage \
	-DCOVERAGE_DIR=\\\"%{_builddir}\\\" -D_GNU_SOURCE" LGCOV="-lgcov" \
%else
export LDFLAGS="$RPM_LD_FLAGS"
make CFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE -DVERSION=\\\"%{version}-%{release}\\\""
%endif

%install
export ARCH=%{_arch}
rm -rf $RPM_BUILD_ROOT
%if %_coverage
make install CFLAGS="-fprofile-arcs -ftest-coverage" LGCOV="-lgcov" \
	DESTDIR=$RPM_BUILD_ROOT \
	SBINDIR=%{_sbindir} \
	MANDIR=%{_mandir} \
	NETSCRIPTDIR=%{_netdir} \
	VZDIR=%{_vzdir} \
	CONFDIR=%{_confdir} \
	VZLOCKDIR=%{_lockdir} \
	VZCTLLOCKDIR=%{_vzctl_lockdir} \
	VZSPOOLDIR=%{_spooldir} \
	BASHCOMPLDIR=%{_bashcompldir} \
	LOGRDIR=%{_logrdir}
rm -fr ${RPM_BUILD_ROOT}/%_incdir
mkdir -p ${RPM_BUILD_ROOT}/%_builddir/%{_basename}
cp -a * ${RPM_BUILD_ROOT}/%_builddir/%{_basename}
%else
make install \
	DESTDIR=$RPM_BUILD_ROOT \
	SBINDIR=%{_sbindir} \
	MANDIR=%{_mandir} \
	NETSCRIPTDIR=%{_netdir} \
	VZDIR=%{_vzdir} \
	CONFDIR=%{_confdir} \
	VZLOCKDIR=%{_lockdir} \
	VZCTLLOCKDIR=%{_vzctl_lockdir} \
	VZSPOOLDIR=%{_spooldir} \
	BASHCOMPLDIR=%{_bashcompldir} \
	LOGRDIR=%{_logrdir}
mkdir -p %{buildroot}%{_docdir}/%{name}-%{version}
install -m 644 COPYING %{buildroot}%{_docdir}/%{name}-%{version}/
%endif

rm -f %{buildroot}%{_sbindir}/vzcpucheck \
    %{buildroot}%{_mandir}/man8/vzcpucheck.8* \
    %{buildroot}%{_mandir}/man8/vzcfgscale.8* \
    %{buildroot}%{_mandir}/man8/vzcfgvalidate.8*

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%dir %attr(755,root,root) %{_vzdir}
%dir %attr(755,root,root) %{_confdir}
%dir %attr(755,root,root) %{_namesdir}
%dir %attr(755,root,root) %{_dracutmodulesdir}
%attr(755,root,root) %{_dracutmodulesdir}/*
%attr(755,root,root) %{_vzdir}/dev
%attr(755,root,root) %{_vzdir}/vzevent.d
%attr(700,root,root) %{_lockdir}
%attr(755,root,root) %{_spooldir}
%attr(755,root,root) %{_bashcompldir}
%attr(755,root,root) %{_sbindir}/vzctl
%attr(755,root,root) %{_sbindir}/vztactl
%attr(755,root,root) %{_sbindir}/ndsend
%attr(755,root,root) %{_sbindir}/ubclogd
%attr(755,root,root) %{_sbindir}/vzsplit
%attr(755,root,root) %{_sbindir}/vzpurge
%attr(755,root,root) %{_sbindir}/vzgetpa
#%attr(755,root,root) %{_sbindir}/vzcpucheck
%attr(755,root,root) %{_sbindir}/vzdiskcheck
%attr(755,root,root) %{_sbindir}/vznetstat
%attr(755,root,root) %{_sbindir}/vzpid
#%attr(755,root,root) %{_sbindir}/vzreboot
%attr(755,root,root) %{_sbindir}/vzauth
%attr(755,root,root) %{_sbindir}/vzlist
%attr(755,root,root) %{_sbindir}/vzeventd
%attr(755,root,root) %{_sbindir}/user_beancounters.py
%attr(644,root,root) %{_unitdir}/vzevent.service
%attr(644,root,root) %{_unitdir}/vz.service
%attr(644,root,root) %{_unitdir}/vz-k8s-inside-ct.service
%attr(755,root,root) %{_libexecdir}/vz*
%attr(644,root,root) %{_logrdir}/vzctl
%attr(644,root, root) %{_confdir}/*sample
%attr(644, root, root) %{_mandir}/man8/vzctl.8.*
%attr(644, root, root) %{_mandir}/man8/ubclogd.8.*
%attr(644, root, root) %{_mandir}/man8/vzpurge.8.*
%attr(644, root, root) %{_mandir}/man8/vzgetpa.8.*
%attr(644, root, root) %{_mandir}/man8/vzsplit.8.*
%attr(644, root, root) %{_mandir}/man8/vznetstat.8.*
#%attr(644, root, root) %{_mandir}/man8/vzcpucheck.8.*
%attr(644, root, root) %{_mandir}/man8/vzdiskcheck.8.*
%attr(644, root, root) %{_mandir}/man8/vzpid.8.*
#%attr(644, root, root) %{_mandir}/man8/vzcfgscale.8.*
#%attr(644, root, root) %{_mandir}/man8/vzcfgvalidate.8.*
%attr(644, root, root) %{_mandir}/man8/vzauth.8.*
%attr(644, root, root) %{_mandir}/man8/vztactl.8.*
%attr(644, root, root) %{_mandir}/man8/vzlist.8.*
#%attr(644, root, root) %{_mandir}/man8/vzreboot.8.*
%attr(644, root, root) %{_mandir}/man8/vzeventd.8.*
%attr(644, root, root) %{_mandir}/man5/ve.conf.5.*
%attr(644, root, root) %{_mandir}/man5/vz.5.*
%attr(644, root, root) %{_mandir}/man5/vz-net_add.5.*
%attr(644, root, root) %{_mandir}/man5/vz-net_del.5.*
%attr(644, root, root) %{_mandir}/man5/vz-create_prvt.5.*
%attr(644, root, root) %{_mandir}/man5/vz-start.5.*
%attr(644, root, root) %{_mandir}/man5/vz-stop.5.*
%attr(644, root, root) %{_mandir}/man5/vz-postinst.5.*
%attr(644, root, root) %{_mandir}/man5/networks_classes.5.*
%if %_coverage
%attr(644,root,root) %{_vzdir}/technologies
%attr(644,root,root) %{_builddir}/%{_basename}
%endif

%attr(644, root, root) %config(noreplace) %{_confdir}/networks_classes
%attr(644, root, root) %config(noreplace) %{_vzdir}/vz.conf
%attr(644, root, root) %config(noreplace) %{_sysconfdir}/modprobe.d/*.conf
%attr(644, root, root) %config %{_sysconfdir}/sysctl.d/*.conf
%attr(644, root, root) %config %{_sysconfdir}/modules-load.d/*.conf
%{_docdir}/%{name}-%{version}


%pre
if [ -L /etc/vz/vz.conf -a -f /etc/sysconfig/vz ]; then
	mv -f /etc/sysconfig/vz /etc/vz/vz.conf
	ln -s /etc/vz/vz.conf /etc/sysconfig/vz
fi
exit 0

%post
/bin/rm -rf /dev/vzctl
/bin/mknod -m 600 /dev/vzctl c 126 0
/bin/rm -rf %{_vzdir}/dev/vzlink
/bin/mknod -m 600 %{_vzdir}/dev/vzlink c 125 0

if [ -f %{_configdir}/vz ]; then
	if ! grep "OFFLINE_SERVICE=" %{_configdir}/vz >/dev/null 2>&1; then
		echo 'OFFLINE_SERVICE="vzpp vzpp-plesk vzpp-desktop"' >> %{_configdir}/vz
	fi
	if ! grep "USE_VENET_MASK=" %{_configdir}/vz >/dev/null 2>&1; then
		echo 'USE_VENET_MASK=yes' >> %{_configdir}/vz
	fi
	if ! grep "IPTABLES=" %{_configdir}/vz >/dev/null 2>&1; then
		echo 'IPTABLES="ipt_REJECT ipt_tos ipt_limit ipt_multiport iptable_filter iptable_mangle ipt_TCPMSS ipt_tcpmss ipt_ttl ipt_length"' >> %{_configdir}/vz
	fi
	if grep "^PLESK_PORT" %{_configdir}/vz >/dev/null 2>&1; then
		sed -e 's/^PLESK_PORT=\(.*\)/#\ PLESK_PORT=\1/' < %{_configdir}/vz > %{_configdir}/vz.tmp && mv -f %{_configdir}/vz.tmp %{_configdir}/vz 2>/dev/null
	fi
	if ! grep -qE "^HTTP_PROXY=" %{_configdir}/vz >/dev/null 2>&1; then
		echo 'HTTP_PROXY=""' >> %{_configdir}/vz
	fi
	if grep -qE "^CONFIGFILE=\"vps.basic\"" %{_configdir}/vz; then
		sed -i 's/CONFIGFILE=\"vps.basic\"/CONFIGFILE="basic"/' %{_configdir}/vz
	fi
	if grep -qE "^VEFORMAT=" %{_configdir}/vz; then
		sed -i 's/VEFORMAT=/VEFSTYPE=/' %{_configdir}/vz
	fi
	if ! grep -qE "PFCACHE_INCLUDES=" %{_configdir}/vz >/dev/null 2>&1; then
		echo 'PFCACHE_INCLUDES="bin etc lib lib64 opt sbin usr"' >> %{_configdir}/vz
	fi
	if ! grep -qE "PFCACHE_IMAGE=" %{_configdir}/vz >/dev/null 2>&1; then
		echo 'PFCACHE_IMAGE="/vz/pfcache.hdd"' >> %{_configdir}/vz
	fi
	if ! grep -qE "PFCACHE=" %{_configdir}/vz >/dev/null 2>&1; then
		echo 'PFCACHE="/vz/pfcache"' >> %{_configdir}/vz
	fi
	if ! grep -qE "OFFLINE_SERVICE=.*vzpp-desktop.*" %{_configdir}/vz >/dev/null 2>&1; then
		 sed -i -e 's/OFFLINE_SERVICE="\(.*\)"/OFFLINE_SERVICE="\1 vzpp-desktop"/' %{_configdir}/vz
	fi
fi
if grep -q -E "CentOS" /etc/redhat-release 2>/dev/null; then
	[ -f /etc/profile.d/vz.sh ] && rm -f /etc/profile.d/vz.sh 2>/dev/null
	[ -f /etc/profile.d/vz.csh ] && rm -f /etc/profile.d/vz.csh 2>/dev/null
	if grep -q "LD_ASSUME_KERNEL=2.4.19" /etc/environment 2>/dev/null; then
                sed -e 's/LD_ASSUME_KERNEL=2.4.19.*//' < /etc/environment > /etc/environment.tmp && mv -f /etc/environment.tmp /etc/environment
	fi
fi
if grep -q -E "3 \(Taroon|CentOS release 3" /etc/redhat-release 2>/dev/null; then
	mkdir -p /etc/profile.d/
	echo '#!/bin/bash
uname -r | grep -q -E "^2.4.20"
[ $? -eq 0 -a -f /proc/vz/veinfo ] && export LD_ASSUME_KERNEL=2.4.19' > /etc/profile.d/vz.sh
	chmod 755 /etc/profile.d/vz.sh
	echo '#!/bin/bash
uname -r | grep -q -E "^2.4.20"
[ $? -eq 0 -a -f /proc/vz/veinfo ] && setenv LD_ASSUME_KERNEL 2.4.19' > /etc/profile.d/vz.csh
	chmod 755 /etc/profile.d/vz.csh
fi

rm -f /etc/modprobe.d/parallels.conf > /dev/null 2>&1

REBOOT_EVENT_FNAME=/sys/module/vzevent/parameters/reboot_event
if grep -q 0 $REBOOT_EVENT_FNAME 2>/dev/null; then
	echo 1 > $REBOOT_EVENT_FNAME
fi

# Load sysctls
/usr/sbin/sysctl -p /etc/sysctl.d/99-vzctl.conf > /dev/null 2>&1

# First installation, not upgrade.
if [ "$1" == "1" ]; then
	# Insert iptables rules.
	%{_libexecdir}/vz-iptables-config.py add > /dev/null 2>&1
fi

:

%systemd_post vzevent.service
%systemd_post vz.service

%preun
%systemd_preun vzevent.service
%systemd_preun vz.service

# Last deinstallation, not upgrade.
if [ "$1" == "0" ]; then
	# Remove iptables rules.
	%{_libexecdir}/vz-iptables-config.py remove > /dev/null 2>&1
fi

:

%postun
%systemd_postun_with_restart vzevent.service

%triggerin -- mlocate
updatedbf="/etc/updatedb.conf"
vzpart="/vz"
[ ! -f $updatedbf ] && exit 0
for i in `cat $updatedbf | grep ^PRUNEPATHS | sed -e "s,.* \",,g" -e "s,\",,g" 2>/dev/null`; do
	[ $i = $vzpart ] && exit 0
done
sed "s/\(^PRUNEPATHS.*\)\"/\1 \\$vzpart\"/" -i $updatedbf > /dev/null 2>&1
:

%changelog
* Mon Jun 27 2022 Konstantin Bukharov <bkb@virtuozzo.com> 7.0.254
 - BUGFIX cache getting cpuinfo in vzlist to fix PSBM-140574

* Tue Jun 14 2022 Konstantin Bukharov <bkb@virtuozzo.com> 7.0.253
 - Change default OS template in /etc/vz/vz.conf to AlmaLinux-8 PSBM-140467

* Tue Apr 19 2022 Pavel Vokhmyanin <pvokhmyanin@virtuozzo.com> 7.0.252
 - Load vzevent module before starting service #VSTOR-52643

* Mon Apr 11 2022 Pavel Vokhmyanin <pvokhmyanin@virtuozzo.com> 7.0.251
 - Load vz-related modules on service start #PSBM-139428
 - Skip autostart if prlctl is missing #PSBM-139428

* Mon Oct 11 2021 Igor Sukhih <igor@virtuozzo.com> 7.0.249
 - vzlist: display Ct type #PSBM-134598

* Fri Jul 02 2021 Igor Sukhih <igor@virtuozzo.com> 7.0.248
 - tune fs.file-max to unlimited #PSBM-80851
 - style: remove dup log message

* Fri Jun 11 2021 Igor Sukhih <igor@virtuozzo.com> 7.0.246
 - Add script user_beancounters.py emulating /proc/user_beancounters (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-130372)

* Wed Jun 09 2021 Igor Sukhih <igor@virtuozzo.com> 7.0.245
 - Supported "vzctl console" without vtty kernel driver. (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-83150)

* Thu May 20 2021 Igor Sukhih <igor@virtuozzo.com> 7.0.243
 - Add 'Wants=proc-sys-fs-binfmt_misc.mount' to vz.service (Denis Silakov
<dsilakov@virtuozzo.com>) (#PSBM-129498)

* Thu Apr 22 2021 Igor Sukhih <igor@virtuozzo.com> 7.0.242
 - Start vz.service after remote-fs target (Denis Silakov
<dsilakov@virtuozzo.com>) (#PSBM-127669)

* Fri Jan 29 2021 Igor Sukhih <igor@virtuozzo.com> 7.0.241
 - Cannot install fuse package inside the container #PSBM-102537

* Tue Jan 26 2021 Igor Sukhih <igor@virtuozzo.com> 7.0.240
 - increase default sysctl values: net.core.rmem_max and net.core.wmem_max
\#PSBM-121988

* Tue Jan 26 2021 Igor Sukhih <igor@virtuozzo.com> 7.0.239
 - Run in shell logic moved to libvzctl

* Thu Nov 19 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.236
 - Prohibit stateless bindmounts #PSBM-122099

* Mon Aug 03 2020 Denis Silakov <dsilakov@virtuozzo.com> 7.0.229-2
 - Drop deprecated tools #PSBM-96948

* Tue Jul 21 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.229
 - Container repair functionality #PSBM-105228

* Tue Jul 07 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.228
 - systemd service to enable "k8s inside a CT" feature #PSBM-102059

* Tue May 26 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.227
 - Do not emit VZCTL_ENV_CONFIG_CHANGED event

* Fri Apr 24 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.226
 - systemd.d/vz: clean lock dir on system boot #PSBM-103219

* Thu Apr 23 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.225
 - Run cloud-init inside Container #PSBM-102953
 - Support host openvswitch bridges for Containers networking #PSBM-102957

* Wed Mar 25 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.221
 - Fixed tupo #PSBM-102538

* Tue Mar 24 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.220
 - add vzctl compact command (Sergei A Mamonov <mrqwer88@gmail.com>)

* Thu Mar 19 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.219
 - Refactor update_ip and netif filter code #PSBM-101760 (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>)
 - add --distribution support to vzctl set (Sergei A Mamonov
<mrqwer88@gmail.com>)
 - add distribution support to vzlist (Sergei A Mamonov <mrqwer88@gmail.com>)
 - refactor configured_ip support for vzlist (Sergei A Mamonov
<mrqwer88@gmail.com>)

* Tue Mar 10 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.218
 - Do not whitelist cpus unconditionally #PSBM-98309 (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>)

* Tue Mar 03 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.217
 - Adjust cpu sysfs visibility #PSBM-98309 (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>)

* Wed Feb 19 2020 Igor Sukhih <igor@virtuozzo.com> 7.0.216
 - vzlist: get actual limits for diskspace,diskinodes #PSBM-101504

* Wed Oct 02 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.209
 - Allow to skip enter lock for exec action #PSBM-98231

* Tue Sep 24 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.208
 - firewalld not able to start in centos 7.7 container #PSBM-98061 #PSBM-98041

* Thu Aug 08 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.207
 - Unable to automount secondary disk under debian-10 #PSBM-96828
 - remove restore from help (Sergei A Mamonov <mrqwer88@gmail.com>)
 - add exec3 and execaction to man (Sergei A Mamonov <mrqwer88@gmail.com>)
 - Add to --help restore, exec3, execaction (Sergei A Mamonov
<mrqwer88@gmail.com>)
 - add some lost vzctl commands to  bash completion (Sergei A Mamonov
<mrqwer88@gmail.com>)

* Mon Jul 15 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.206
 - systemd.d/vz: VE_PARALLEL does not work

* Wed Jul 03 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.205
 - man/vz.5 add REPAIR_MODE desc #PSBM-95789
 - man/vz.5: remove deprecated parameters
 - Remove error codes dup

* Wed Jun 19 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.204
 - Not able to restart CT from inside if backup is currently running #PSBM-95607
 - vzlist: display time features

* Fri Jun 07 2019 Konstantin B. Bukharov <bkb@virtuozzo.com> 7.0.203
 - man/vzctl.8 add 'time' feature (Igor Sukhih <igor@virtuozzo.com>)

* Thu May 30 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.202
 - /bin/rm: cannot remove Directory not empty #PSBM-94581
 - Update Copyright

* Thu Mar 21 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.201
 - configure ve.netif_max_nr parameter per Container #PSBM-92143

* Wed Mar 20 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.200
 - Renew copyright information (ykargin@virtuozzo.com <ykargin@virtuozzo.com>)
 - Actualise copyright information. Make 'vzctl create' autocompletion works
with UUIDs (ykargin@virtuozzo.com <ykargin@virtuozzo.com>)

* Mon Mar 18 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.199
 - man: remove deprecated ve-alias_add.5 ve-alias_del.5 ve-veconfig.5
\#PSBM-92141
 - Edits to scripts location in man pages. Fixes PSBM-92141 (Alyona Migai
<amigai@virtuozzo.com>)

* Wed Mar 13 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.197
 - Skip HA registration by demand on start/resume

* Mon Feb 25 2019 Igor Sukhih <igor@virtuozzo.com> 7.0.195
 - increase sysctl "net.core.netdev_max_backlog #PSBM-90791

* Tue Dec 18 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.192
 - Set stop as default value for VE_STOP_MODE #PSBM-89623

* Mon Oct 01 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.191
 - etc/systemd.d/vz: vz service start failed #PSBM-89044
 - man/vzctl.8: update error code
 - Revert "PSBM-59468 increase ipv4 and ipv6 ARP tables until its virtualization

* Mon Jul 30 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.190
 - PSBM-59468 increase ipv4 and ipv6 ARP tables until its virtualization -
PSBM-87155 (Konstantin B. Bukharov <bkb@virtuozzo.com>)

* Wed Jul 25 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.189
 - systemd.d/vz: vz service restart does not start CTs back #PSBM-78956
 - Container couldn't start if BANDWIDTH was set incorrectly #PSBM-65642

* Tue Jul 10 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.188
 - vzlist: NULL pointer dereferrence

* Thu Jun 21 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.187
 - vzlist: use vzctl2_get_net_info() to get ip addresses list
 - systemd.d/vz: fixed grep regular expression

* Thu May 24 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.186
 - vzlist: display origin_sample #PSBM-81315
 - Use single function for print string fields
 - Add layout alias for ve_layout flag for vzctl create (Sergei A Mamonov
<mrqwer88@gmail.com>)

* Tue Mar 20 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.185
 - non-option ARGV-elements: --device-uuid  #PSBM-82602

* Tue Mar 20 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.184
 - Add --ostemplate support for vzctl set (Sergei A Mamonov
<mrqwer88@gmail.com>)

* Tue Feb 27 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.183
 - remove vzctl2_set_vzlimits()
 - Add to vzctl  snapshot --skip-suspend flag (Sergei A Mamonov
<mrqwer88@gmail.com>)

* Wed Jan 24 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.182
 - Display veth IP addresses in vzlist output #PSBM-80811 (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>)
 - we should not use proxy_arp global configuration flag #PSBM-77115
 - Add json flag to vzlist man (Sergei A Mamonov <mrqwer88@gmail.com>)
 - Add json output support for host_ifname,mac,host_mac,gw,network,ifname,netif
(Sergei A Mamonov <mrqwer88@gmail.com>)

* Fri Jan 19 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.181
 - Fix iolimit and iopslimit output (Sergei A Mamonov <mrqwer88@gmail.com>)
 - Add json support for tm (Sergei A Mamonov <mrqwer88@gmail.com>)
 - Add json output support for devnodes (Sergei A Mamonov <mrqwer88@gmail.com>)
 - Add json output support for cpumask, nodemask, autostop, device, ha_prio
(Sergei A Mamonov <mrqwer88@gmail.com>)

* Wed Jan 17 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.180
 - Added initial json support for vzlist (Sergei A Mamonov <mrqwer88@gmail.com>)

* Fri Jan 12 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.179
 - Revert "applyconfig does not set ORIGIN_SAMPLE #PSBM-77823"
 - add nameserver and searchdomain to vzlist (Sergei A Mamonov
<mrqwer88@gmail.com>)
 - add cpus to vzlist (Sergei A Mamonov <mrqwer88@gmail.com>)
 - Add disabled to vzlist (Sergei A Mamonov <mrqwer88@gmail.com>)
 - cleanup: removed unused code

* Wed Jan 10 2018 Igor Sukhih <igor@virtuozzo.com> 7.0.177
 - add nameserver and searchdomain to vzlist (Sergei A Mamonov
<mrqwer88@gmail.com>)
 - add cpus to vzlist (Sergei A Mamonov <mrqwer88@gmail.com>)
 - Add disabled to vzlist (Sergei A Mamonov <mrqwer88@gmail.com>)
 - cleanup: removed unused code

* Wed Dec 20 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.176
 - Revert "we should not use proxy_arp global configuration flag #PSBM-77115"

* Mon Dec 18 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.175
 - applyconfig does not set ORIGIN_SAMPLE #PSBM-77823
 - we should not use proxy_arp global configuration flag #PSBM-77115
 - Add "do not modify" header to sysctl config file

* Mon Nov 20 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.174
 - Use the Server UUID from 'prlsrvctl info' rather than generating new one
\#PSBM-77410

* Mon Sep 25 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.173
 - Image always recreated on --device-add #PSBM-72849

* Fri Sep 22 2017 Konstantin Volkov <wolf@virtuozzo.com> 7.0.172-2
- Drop /var/lock/vzctl from rpm filelist, see #PSBM-39773

* Fri Sep 22 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.172
 - --skip-dump is missing in vzctl #PSBM-72748
 - recreate ploop disk image #PSBM-71894

* Thu Aug 31 2017 bkbbkb <bkb@virtuozzo.com> 7.0.171
 - Increase default number of available namespaces #PSBM-69675 (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>)

* Fri Aug 18 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.170
 - Set up the limit for memory sub cgroups on Container start #PSBM-58983
 - Limit number of memory sub-cgroups available to be created inside a CT
\#PSBM-58983

* Wed Aug 16 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.169
 - ve-fserror: handle multiple fserror race #PSBM-70077

* Tue Aug 15 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.168
 - vzlist output truncated when multiple variables requested #PSBM-69682
 - modules-load.d/vz.conf: remove ploop related modules

* Tue Aug 08 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.167
 - It is not possible to set quotaugidlimit for a running containe #PSBM-69802

* Thu Aug 03 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.166
 - Host ownership identification for containers #PSBM-69099

* Tue Aug 01 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.165
 - Owner check failed: Container private area is not set #PSBM-69468

* Mon Jul 31 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.164
 - vzevent.d/ve-fserror: dont stop CT by default

* Fri Jul 28 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.163
 - vzevent.d/ve-fserror: ploop is not unmounted #PSBM-69295

* Thu Jul 27 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.162
 - ve-fserror: use sysfs to find CTID by ploop device

* Wed Jul 26 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.161
 - Unable to stop Ct #PSBM-69128

* Wed Jul 26 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.159
 - Fixed compilation
 - vzeventd: process both ABORT & ERROR uevent to trigger fserror

* Tue Jul 25 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.157
 - vzeventd: process ext4 ABORT uevent to trigger fserror #PSBM-68848

* Mon Jul 24 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.156
 - Emit VZCTL_ENV_CONFIG_CHANGED event on CT config update #PSBM-68755
 - vzeventd.c: poll(): Interrupted system call

* Tue Jul 18 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.154
 - Allow /sys/module directory access for Containers by default #PSBM-68296
 - fixed use of vzctl2_alloc_env_param()

* Fri Jun 30 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.153
 - Remove suspend related action for ON_VE_FSERROR

* Thu Jun 22 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.152
 - Configurable behaviour for fserror event #PSBM-66619
 - Take into account VE_PARALLEL gloabl parameter
 - Remove CPT_SUSPEND_TIMEOUT global parameter

* Wed Jun 21 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.151
 - preload "ip_vs" module on the host #PSBM-65536

* Tue Jun 20 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.150
 - vzevents: process file system error event #PSBM-66619

* Tue May 30 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.149
 - Remove Vz-specific oom odjusment #PSBM-56344

* Tue May 30 2017 Andrey Bondrov <abondrov@virtuozzo.com> 7.0.148-3
- Enable hardened build, see #PSBM-58107

* Tue Apr 18 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.148
 - Makefile: remove iptables-config.py from install target

* Tue Apr 18 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.147
 - Use iptables-config from virtuozzo-release #PSBM-64649

* Tue Apr 18 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.146-2
 - Use iptables-config from virtuozzo-release (#PSBM-64649)

* Fri Apr 14 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.146
 - --quiet option does not work

* Fri Apr 14 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.145
 - *-.conf-sample: Remove VM_OVERCOMMIT from samles #PSBM-39196

* Thu Mar 30 2017 Konstantin Volkov <wolf@virtuozzo.com> 7.0.144
 - More rebranding, see #PSBM-58317

* Fri Mar 24 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.143
 - drop setting fixed value for fs.file-max in sysctl.conf #PSBM-62520

* Mon Feb 27 2017 Konstantin Volkov <wolf@virtuozzo.com> 7.0.142
 - Drop DEFAULT_PRODUCT_NAME_SHORT, see #PSBM-58317
 - Rebrand visible labels, see #PSBM-58317
 - vzsplit: reformat log message (Igor Sukhih <igor@virtuozzo.com>)

* Tue Feb 14 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.141
 - vzlist: incorect status for paused CT #PSBM-60515

* Mon Feb 13 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.140
 - vzlist: sKip processing 127/8 loopback network #PSBM-60294
 - vzauth: show proper error if .psa.shadow is absent #PVA-36225

* Fri Feb 03 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.139
 - vzauth: show proper error if .psa.shadow is absent #PVA-36225

* Mon Jan 30 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.138
 - CT pause action ##PSBM-55237

* Fri Jan 20 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.137
 - fixed build

* Wed Jan 18 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.136
 - change ostemplate on reinstall

* Mon Jan 16 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.135
 - Increase kernel.pid_max in userspace via /etc/sysctl.conf PSBM-55365

* Thu Jan 12 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.134
 - Add autoload of br_netfilter module PSBM-58398

* Tue Jan 10 2017 Igor Sukhih <igor@virtuozzo.com> 7.0.133
 - /etc/modprobe.d/vz.conf line 2: ignoring bad line starting with 'options
nf_conntrack' #PSBM-58248
 - Added zsh compatiblity. (Parth Kolekar <superstarpk@gmail.com>)

* Fri Dec 16 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.132
 - Do not show kernel addresses inside Containers #PSBM-55923

* Wed Dec 14 2016 Konstantin Volkov <wolf@virtuozzo.com> - 7.0.131-2
- Rebuild in 7.3 environment

* Wed Dec 14 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.131
 - "vzctl set <CTID> --netif_mac_renew" drops DHCP flag #PSBM-57170

* Tue Dec 13 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.121.3
 - "vzctl set <CTID> --netif_mac_renew" drops DHCP flag #PSBM-57170

* Mon Dec 05 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.130
 - Revert 3ce3ac6c

* Mon Dec 05 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.129
 - Extend register syntax #PSBM-56392

* Thu Dec 01 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.128
 - Regenerate veth MAC #PSBM-56389

* Wed Nov 09 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.127
 - Failed to resize in offline mode #PSBM-55095

* Mon Nov 07 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.126
 - Don't configure "ip_conntrack_disable_ve0" module option #PSBM-52080

* Wed Oct 26 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.125
 - lscpu does not works inside container #PSBM-54313

* Wed Oct 19 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.124
 - Make "NETFILTER=full" for Containers by default #PSBM-51646

* Tue Oct 18 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.123
 - Functionality to turn on dont send event mode #PSBM-53912

* Wed Oct 12 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.122
 - vzevent.d/ve-stop: change detection CT stop reason #PSBM-53320

* Mon Oct 10 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.120
 - Temporary make "NETFILTER=stateless" inside Containers by default #PSBM-53455
 - bash_completion.d: add complition for encryption oprions

* Fri Oct 07 2016 Konstantin Volkov <wolf@virtuozzo.com> 7.0.119
 - Change timeout to 1h for vz service, see #PSBM-53325

* Fri Oct 07 2016 Konstantin Volkov <wolf@virtuozzo.com> 7.0.118
 - Implement infinity stop timeout for vz service, see #PSBM-53300

* Wed Sep 28 2016 Valentin Kulesh <valentin.kulesh@virtuozzo.com> 7.0.117-2
 - Add a requirement for ethtool #PSBM-52670

* Thu Sep 22 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.117
 - --reencrypt option does not work

* Wed Sep 21 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.116
 - src/Makefile: fixed compilation

* Wed Sep 21 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.115
 - "vzctl console -s" doesn't start getty in container #PSBM-52446
 - vzeventd: dont use /bin/ps in ve-stop script

* Fri Sep 16 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.114
 - vzlist: show real ip addresses #PSBM-52208

* Thu Sep 15 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.113
 - Disk encryption support encrypt/decrypt/changekey #PSBM-52087

* Tue Sep 13 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.112
 - Support persistent control of pagecache isolation for CT #PSBM-32384
 - Make "NETFILTER=full" for Containers by default #PSBM-51646
 - Use autostop parameter on service vz stop
 - vzlist: display autostop mode
 - CT autostop functionality #PSBM-50873
 - Add veth module to autoload at HN startup: needed for docker functionality

* Fri Sep  9 2016 Konstantin Volkov <wolf@virtuozzo.com> 7.0.111-2
- Change /vz/lock permissions to 0700, see #PSBM-51897

* Wed Sep 07 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.111
 - Use autostop parameter on service vz stop
 - vzlist: display autostop mode
 - CT autostop functionality #PSBM-50873
 - Add veth module to autoload at HN startup: needed for docker functionality

* Mon Sep 05 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.110
 - Add veth module to autoload: needed for docker

* Thu Sep 01 2016 Konstantin Volkov <wolf@virtuozzo.com> 7.0.109
 - Always load overlay kernel module on HN startup, see #PSBM-51645
 - Implement vzevent service autorestart, see #PSBM-51403

* Mon Aug 15 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.108
 - Disk encryption support

* Wed Jul 27 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.107
 - Process --name argument on register action  #PSBM-50026

* Mon Jul 25 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.106
 - vznetstat: unable to list stat by ctid #PSBM-50088
 - mark /etc/modprobe.d/vz.conf as noreplace #PSBM-49291

* Mon Jun 27 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.105
 - Restore 'vz shaperrestart' action #PSBM-42178

* Tue Jun 21 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.104
 - vzctl.8: remove ipgre deprecated feature #PSBM-48597
 - Removed mentions of unsupported --device-add and --device-del #PSBM-47295

* Tue Jun 14 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.103
 - Wait for vstorage-fs.service on start (if exists) #PSBM-32528
 - Move post-install module options to vz.conf, #PSBM-48263

* Wed Jun 08 2016 Konstantin Volkov <wolf@virtuozzo.com> 7.0.102
 - Do not fail on start if shaman absent, see #PSBM-48114

* Mon Jun 06 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.101
 - Cleanup stale CT registrations on vz service start, #PSBM-47892

* Fri Jun 03 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.100
 - Unable to cancerll exec operation #PSBM-47870

* Thu Jun 02 2016 Igor Sukhih <igor@virtuozzo.com> 7.0.99
 - Enable proxy arp, #PSBM-44285

* Tue May 17 2016 Dmitry Mishin <dim@virtuozzo.com> 7.0.98
 - Port sysctl tweaks from Vz6 (Alexander Kurbatov <alkurbatov@virtuozzo.com>)
   (#PSBM-47204 #PSBM-14024 #PSBM-15106)

* Tue Apr 19 2016 Igor Sukhih <igor@parallels.com> 7.0.97
 - CT resumed on node start with ONBOOT=no #PSBM-46337

* Sat Apr 16 2016 Igor Sukhih <igor@parallels.com> 7.0.96
 - added processing --setmode parameter #PSBM-32894

* Fri Apr 15 2016 Igor Sukhih <igor@parallels.com> 7.0.95
 - incorrect behavior for DEVNODES parameter on applying config #PSBM-34160

* Thu Apr 14 2016 Igor Sukhih <igor@parallels.com> 7.0.94
 - Suspend CT on vz service stop #PSBM-34928

* Thu Apr 14 2016 Igor Sukhih <igor@parallels.com> 7.0.93
 - Delayed /vz mounting support #PSBM-35278
 - veth specific parameters are skipped if --netif_add used without --ifbane
\#PSBM-35045
 - vz.conf: return back DUMPDIR #PSBM-46016

* Fri Apr 01 2016 Igor Sukhih <igor@parallels.com> 7.0.92
 - code cleanup

* Mon Mar 28 2016 Igor Sukhih <igor@parallels.com> 7.0.91
 - Process --storage-url disk parameter #PSBM-45496
 - Remove obsoleted VE0CPUUNITS PSBM-44940
 - Remove obsoleted VZPRIVRANGE PSBM-44986

* Thu Mar 24 2016 Igor Sukhih <igor@parallels.com> 7.0.90
 - Corresponding value for mysqld was not added toPID/oom_score_adj in CT
 - vz.5: remove OVERCOMMITMENT_* parameter
 - vz.conf: remove VERCOMMITMENT_* parameters
 - vz.conf: remove DUMPDIR parameter PSBM-44987
 - Removed obsoleted CAPABILITY parameter PSBM-45004
 - Fixed templates options descriptions PSBM-45007 PSBM-45006
 - Updated cpuunits description PSBM-45012
 - Fixed disk quota description PSBM-45013

* Wed Mar 16 2016 Igor Sukhih <igor@parallels.com> 7.0.89
 - Unable to register CT with --start

* Wed Mar 09 2016 Igor Sukhih <igor@parallels.com> 7.0.88
 - Functionalit to create ploop major:minor map #PSBM-44417

* Sat Feb 27 2016 Konstantin <wolf@parallels.com> 7.0.87
 - Drop modules-load.d vz.conf from dracut initrd image, see #PSBM-44573
 - Allow passing additional CFLAGS to build process (Denis Silakov
<dsilakov@gmail.com>)
 - Update --memguarantee auto description #PSBM-43671 (Igor Sukhih
<igor@parallels.com>)

* Tue Feb 02 2016 Igor Sukhih <igor@parallels.com> 7.0.86
 - oom-groups.conf: Make sure init is the last to be OOM-killed
 - Wrong flag set for skip_app_templates
 - Fix typo in param help

* Tue Jan 26 2016 Igor Sukhih <igor@parallels.com> 7.0.85
 - Fixed compilation

* Tue Jan 26 2016 Igor Sukhih <igor@parallels.com> 7.0.84
 - Add tty[0-12] into default permissions

* Tue Jan 26 2016 Igor Sukhih <igor@parallels.com> 7.0.83
 - Support memory guarantees  #PSBM-43142

* Mon Jan 11 2016 Igor Sukhih <igor@parallels.com> 7.0.82
 - vzeventd: Cleanup CT resources on stop action #PSBM-42820
 - vz.conf: updated iface name for RATEMPU #PSBM-41805
 - Installation of vzctl onto centos-7 HN prints warning #PSBM-41421

* Tue Dec 01 2015 Igor Sukhih <igor@parallels.com> 7.0.81
 - vz.conf: updated iface name for BANDWIDTH #PSBM-41805

* Fri Nov 27 2015 Igor Sukhih <igor@parallels.com> 7.0.80
 - Dispaly warning message on use --capability #PSBM-40834

* Fri Nov 27 2015 Igor Sukhih <igor@parallels.com> 7.0.79
 - vzlist: resurrect display latency info

* Fri Nov 27 2015 Igor Sukhih <igor@parallels.com> 7.0.78
 - vzlist remove unused update_ves_io_info()
 - vzlist: collect runtiem configuration #PSBM-41333

* Wed Nov 11 2015 Igor Sukhih <igor@parallels.com> 7.0.77
 - Fixed description of iolimit metric #PSBM-40339
 - Updated default OS template to the latest CentOS version #PSBM-38750
 - Fix binary version in non-rpm build #PSBM-40438
 - load network classes configuration on vz.service start #PSBM-40831

* Fri Nov 06 2015 Igor Sukhih <igor@parallels.com> 7.0.76
 - load network classes configuration on vz.service start #PSBM-40831

* Tue Oct 27 2015 Igor Sukhih <igor@parallels.com> 7.0.75
 - Restore 'vzctl setrate' functionality #PSBM-40697

* Mon Oct 26 2015 Igor Sukhih <igor@parallels.com> 7.0.74
 - Incorrect CT suspended status #PSBM-40663

* Sat Oct 24 2015 Igor Sukhih <igor@parallels.com> 7.0.73
 - vzlist: wrong format of IP on venet0 #PSBM-40464
 - vzlist features shows garbage if no features was set #PSBM-40601

* Sat Oct 24 2015 Igor Sukhih <igor@parallels.com> 7.0.72
 - Remove ifcfg-venet0 ifdown-venet ifup-venet #PSBM-40624
 - Configure venet0 iface form vz service #PSBM-40624

* Wed Oct 07 2015 Igor Sukhih <igor@parallels.com> 7.0.71
 - Update Ploop calls to newer API
 - Modify updatedb.conf to avoid /vz checks, see #PSBM-40070
 - Release up (Konstantin <wolf@parallels.com>)
 - Do exit explicitly (Konstantin <wolf@parallels.com>)
 - Do exit instead of variable check (Konstantin <wolf@parallels.com>)
 - Modify updatedb.conf to avoid /vz checks,#PSBM-40070

* Wed Oct  7 2015 Konstantin Volkov <wolf@odin.com> 7.0.70-2
- Modify updatedb.conf to avoid /vz checks, see #PSBM-40070

* Tue Oct 06 2015 Igor Sukhih <igor@parallels.com> 7.0.70
 - Enable ipv6 forwarding by default, #PSBM-39085

* Wed Sep 23 2015 Igor Sukhih <igor@parallels.com> 7.0.69
 - Deny to access /devices/system/cpu/cpu*/* content inside CT #PSBM-39826

* Wed Aug 26 2015 Igor Sukhih <igor@parallels.com> 7.0.68
 - CT is not started on reboot event #PSBM-38711
 - vzeventd: verbose logging

* Tue Aug 25 2015 Igor Sukhih <igor@parallels.com> 7.0.67
 - Allow access to all files under devices/system/cpu/cpu* inside CT #PSBM-35280

* Tue Aug 25 2015 Igor Sukhih <igor@parallels.com> 7.0.66
 - Allow access to devices/system/cpu/cpu* inside CT #PSBM-35280

* Thu Aug 20 2015 Igor Sukhih <igor@parallels.com> 7.0.65
 - vz.service returns 0 in case of ethtool error, #PSBM-38729

* Wed Aug 12 2015 Igor Sukhih <igor@parallels.com> 7.0.64
 - Added auto value (absent | not {yes,no} ) for USE_NET_{HWCSUM,TSO}, #PSBM-18138 

* Fri Aug 07 2015 Igor Sukhih <igor@parallels.com> 7.0.63
 - Added script to protect host IPs from host-routed containers. #PSBM-21257

* Thu Aug 06 2015 Igor Sukhih <igor@parallels.com> 7.0.62
 - fix uuid problem of vzeventd, #OVZ-6318

* Wed Aug 05 2015 Igor Sukhih <igor@parallels.com> 7.0.61
 - snapshot-list operation failed, #PSBM-35293

* Thu Jul 30 2015 Igor Sukhih <igor@parallels.com> 7.0.60
 - Incorrect CT status reported for deleted CT, #PSBM-35252
 - vzctl should parse uuids on register operation, #PSBM-35248

* Tue Jul 28 2015 Igor Sukhih <igor@parallels.com> 7.0.59
 - vzctl should parse uuids on register operation, #PSBM-35248

* Fri Jul 24 2015 Igor Sukhih <igor@parallels.com> 7.0.57
 - Update default CT sysfs permissions, #PSBM-35146

* Wed Jul 22 2015 Dmitry Mishin <dim@virtuozzo.com> 7.0.56
 - Adopt vzgetpa to Vz 7 layout #PSBM-35081
 - vzlist: obtain inode limits from CT config (Igor Bazhitov
<ibazhitov@virtuozzo.com>)
 - vzlist: show diskspace limits obtained from CT config, not from vzquota
(#PSBM-34924) (Igor Bazhitov <ibazhitov@virtuozzo.com>)

* Mon Jul 20 2015 Konstantin Volkov <wolf@odin.com>> 7.0.55-2
- Do not call vz service restart on upgrade, see #PSBM-35024

* Fri Jul 17 2015 Igor Sukhih <igor@parallels.com> 7.0.55
 - Incorrect CT status, #PSBM-34973

* Thu Jul 16 2015 Igor Sukhih <igor@parallels.com> 7.0.54
 - Deny /sys/block inside CT, #PSBM-33064
 - Remove deprecated vzctl params from usage, man and autocomplete
 - Remove vzfs params from autocomplition #PSBM-34815

* Thu Jul 16 2015 Igor Sukhih <igor@parallels.com> 7.0.53
 - Fix uuid alignment in vzlist, #PSBM-34127
 - Remove --diskinodes, --quotatime from doc, #PSBM-34815
 - Incorrect status displayed for suspended CT

* Mon Jul 13 2015 Konstantin Volkov <wolf@odin.com>> 7.0.52-2
- Added vz.service to rpm scripts

* Mon Jul 13 2015 Dmitry Mishin <dim@virtuozzo.com> 7.0.52
 - Temporary remove vzreboot script installation #PSBM-34849
 - Fixed required libvzctl (Igor Sukhih <igor@parallels.com>)

* Wed Jul 08 2015 Igor Sukhih <igor@parallels.com> 7.0.51
 - vz.service: added vcmmd.service requires

* Wed Jul 08 2015 Igor Sukhih <igor@parallels.com> 7.0.50
 - Allow aaccess to /sys/devices/system/cpu/kernel_max insde CT, #PSBM-34783
 - Add systemd vz.service, #PSBM-34778
 - Added RATEMPU param to config.

* Tue Jul 07 2015 Igor Sukhih <igor@parallels.com> 7.0.49
 - vzlist: CT status is not correct

* Tue Jul 07 2015 Igor Sukhih <igor@parallels.com> 7.0.48
 - vzlist: display devnodes CT configuration parameter, #PSBM-32977

* Mon Jul 06 2015 Igor Sukhih <igor@parallels.com> 7.0.47
 - Fixed short command line options work, #PSBM-33888
 - Remove arpsend as deprecated

* Thu Jul 02 2015 Igor Sukhih <igor@parallels.com> 7.0.45
 - Display CTID in vznestat output, #PSBM-33930

* Wed Jul 01 2015 Igor Sukhih <igor@parallels.com> 7.0.44
 - No output from 'vzctl monitor VEID | tee', #PSBM-34626

* Wed Jul 01 2015 Igor Sukhih <igor@parallels.com> 7.0.43
 - Add ve-stop script to package
 - Error on /etc/vz/vzevent.d/ve-stop
 - Attach to CT console
 - vzlist: duplicate ctid entries

* Mon Jun 22 2015 Igor Sukhih <igor@parallels.com> 7.0.42
 - Remove loading deprecated vz modules, #PSBM-31333

* Fri Jun 19 2015 Igor Sukhih <igor@parallels.com> 7.0.41
 - Remove ip_conntrack_disable_ve0=1, #PSBM-34316

* Thu Jun 18 2015 Igor Sukhih <igor@parallels.com> 7.0.40
 - Add monitor action, #PSBM-34331

* Wed Jun 17 2015 Igor Sukhih <igor@parallels.com> 7.0.39
 - vzlist: display not valid veth related parameter, #PSBM-34255
 - Add README (Sergey Bronnikov <sergeyb@openvz.org>)

* Tue Jun 16 2015 Igor Sukhih <igor@parallels.com> 7.0.38
 - remove "vzethdev" from /etc/modules-load.d/vz.conf, #PSBM-34246

* Mon Jun 15 2015 Igor Sukhih <igor@parallels.com> 7.0.37
 - Unable to manage veth parameters, #PSBM-34191

* Thu Jun 11 2015 Igor Sukhih <igor@parallels.com> 7.0.36
 - Wait does not work for CT restart action, #PSBM-34184

* Wed Jun 10 2015 Igor Sukhih <igor@parallels.com> 7.0.35
 - vzauth: preserve erro rcodes compatibility, #PSBM-33957

* Sat May 30 2015 Konstantin Volkov <wolf@parallels.com> 7.0.34
 - --fast-links is vztar option, drop it

* Sat May 30 2015 Dmitry Mishin <dim@parallels.com> 7.0.33
 - Added libvzctl library initialization to vzauth #PSBM-33877

* Sat May 30 2015 Dmitry Mishin <dim@parallels.com> 7.0.32
 - Return back VEFSTYPE global parameter - it could be useful later

* Fri May 29 2015 Igor Sukhih <igor@parallels.com> 7.0.31
 - Unable to register CT, #PSBM-33877

* Thu May 28 2015 Igor Sukhih <igor@parallels.com> 7.0.30
 - Cleanup VZFS mentions #PSBM-19383
 - Remove unused 'struct CParam' members
 - Remove unused bindmount specific code
 - It's possible to add bindmount to started CT, fixed #PSBM-33824
 - Typo in 'if' experession

* Mon May 25 2015 Igor Sukhih <igor@parallels.com> 7.0.29
 - There no bindmounts in /proc/mounts, #PSBM-33722
 - CT is not locked on create action, #PSBM-33740
 - Mark as deprecated quotaon|quotaoff|quotainit, #PSBM-33731
 - Remove deprecated VZMOUNTS parameter, #PSBM-33720
 - List CT by NAME==VEID, #PSBM-33483

* Fri May 22 2015 Igor Sukhih <igor@parallels.com> 7.0.28
 - Mark as deprecated quotaon|quotaoff|quotainit, see #PSBM-33731
 - Remove deprecated VZMOUNTS parameter, see #PSBM-33720
 - List CT by NAME==VEID, see #PSBM-33483

* Fri May 15 2015 Igor Sukhih <igor@parallels.com> 7.0.27
 - Restore original create syntax

* Thu May 14 2015 Igor Sukhih <igor@parallels.com> 7.0.26
 - vzlist: Incorrect uuid in output
 - vzlist: CTID field is not alligned
 - Set CT name functionality does not work

* Wed May 13 2015 Igor Sukhih <igor@parallels.com> 7.0.25
 - Set CT name functionality does not work

* Tue May 12 2015 Igor Sukhih <igor@parallels.com> 7.0.24
 - vzlist: show ctid with id 0
 - support device for CT disk(s)
 - vzctl_env_create: pass uuid parameter

* Fri May 08 2015 Igor Sukhih <igor@parallels.com> 7.0.23
 - vzctl_env_create: pass uuid parameter

* Tue May 05 2015 Igor Sukhih <igor@parallels.com> 7.0.22
 - change CT id form integer to uuid, use new API

* Tue Apr 21 2015 Igor Sukhih <igor@parallels.com> 7.0.21
 - add autoload vznetdev module, see #PSBM-33102

* Mon Apr 20 2015 Igor Sukhih <igor@parallels.com> 7.0.20
 - remove offline management stuff, see #PSBM-32946

* Thu Apr 16 2015 Konstantin Volkov <wolf@parallels.com> 7.0.19
 - Add ability to list devnodes to vzlist, see #PSBM-32936 @105691

* Wed Apr 15 2015 Konstantin Volkov <wolf@parallels.com> 7.0.18
 - Remove vzredir modules, them dropped in vzkernel, see #PSBM-32932

* Fri Apr 10 2015 Daniil Guzanov <dguzanov@odin.com> 7.0.17
 - Added GPL text

* Fri Apr 10 2015 Daniil Guzanov <dguzanov@odin.com> 7.0.16
 - Updated license #PSBM-26806

* Thu Apr 09 2015 Konstantin Volkov <wolf@parallels.com> 7.0.15-2
 - Mark sysctl conf as noreplace, load it on installation

* Thu Apr 09 2015 Konstantin Volkov <wolf@parallels.com> 7.0.15
 - Create vzctl sysctl config, see #PSBM-32860

* Wed Apr 08 2015 Konstantin Volkov <wolf@parallels.com> 7.0.14
 - Correct conf files path, see #PSBM-32775
 - Change venet0 device type to NetworkManager, see #PSBM-32775

* Tue Apr 07 2015 Daniil Guzanov <dguzanov@odin.com> 7.0.13
 - rebuild with ploop 7.0.x #PSBM-32811

* Fri Mar 27 2015 Igor Sukhih <igor@parallels.com> 7.0.12
 - incorrect UUID in CT config after create #PSBM-32655

* Thu Mar 26 2015 Igor Sukhih <igor@parallels.com> 7.0.11
  vzlist: fixed path to CT config folder

* Mon Mar 23 2015 Igor Sukhih <igor@parallels.com> 7.0.10
- vz.conf: disable PFCACHE parameter #PSBM-32534

* Fri Mar 20 2015 Konstantin Volkov <wolf@parallels.com> 7.0.9
- Added systemd vzevent service unit #PSBM-32527

* Fri Mar 20 2015 Konstantin Volkov <wolf@parallels.com> - 7.0.8
- Initial changelog entry
